"""Color palettes and utilities.

For most plots, BioPsyKit uses FAU's colors scheme.
"""
from biopsykit.colors.colors import (
    FAU_COLORS,
    fau_color_dict,
    fau_palette,
    fau_palette_by_name,
    fau_palette_blue,
    fau_palette_phil,
    fau_palette_med,
    fau_palette_tech,
    fau_palette_wiso,
    fau_palette_nat,
    fau_color,
    adjust_color,
)

__all__ = [
    "FAU_COLORS",
    "fau_color_dict",
    "fau_palette",
    "fau_palette_by_name",
    "fau_palette_blue",
    "fau_palette_phil",
    "fau_palette_med",
    "fau_palette_tech",
    "fau_palette_wiso",
    "fau_palette_nat",
    "adjust_color",
    "fau_color",
]
